%%! -*- coding:utf-8; mode:latex; -*-

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{kit-zar}[2016/06/23 XeLaTeX class for the super ugly requirements of the KIT ZAR]

\LoadClass[11pt,singlepage,titlepage]{article}

\RequirePackage{etoolbox}
\InputIfFileExists{preamble-local.tex}{}{}

\providecommand*{\ConfigMatriculation}{\emph{(verborgen)}}
\providecommand*{\ConfigBiblatexBackend}{biber}

\RequirePackage{fontspec}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage[ttscale=MatchLowercase]{libertine}
%\RequirePackage[libertine]{newtxmath}

\RequirePackage{polyglossia}
\setmainlanguage[spelling=new]{german}

\RequirePackage{geometry}
% This is the most terrible page layout I have ever produced!
\geometry{%
  a4paper,%
  left = 6cm,%
  right = 3cm,%
  top= 3cm,%
  bottom = 3cm,%
}

\RequirePackage{csquotes}
\RequirePackage[%
  backend=\ConfigBiblatexBackend,%
]{biblatex}

\RequirePackage{setspace}
\onehalfspacing

\RequirePackage{enumitem}
\setlist[enumerate]{%
  label = {(\roman*)},%
  parsep = 0ex,%
}

\RequirePackage{fancyhdr}
\pagestyle{fancy}
\fancyhead{}
\fancyfoot{}
\renewcommand*{\headrulewidth}{\z@}
\renewcommand*{\footrulewidth}{\z@}
\fancyhead[L]{\footnotesize\itshape\@author@short, \@title@short.}
\fancyhead[R]{\footnotesize\itshape\bfseries\thepage}

\RequirePackage[pdfborder={0 0 0}]{hyperref}

\newcommand{\preface}{%
  \renewcommand*{\thepage}{\roman{page}}%
}

\newcommand{\mainpart}{%
  \cleardoublepage%
  \setcounter{secnumdepth}{5}%
  \setcounter{page}{1}%
  \renewcommand*{\thepage}{\arabic{page}}%
}

\renewcommand{\appendix}{%
  \cleardoublepage%
  \setcounter{secnumdepth}{0}%
}

\newcounter{@thanks}
\renewcommand{\the@thanks}{\fnsymbol{@thanks}}
\newcommand{\thanks@list}{}

\renewcommand{\maketitle}{%
  \newgeometry{hscale = 0.7, vscale = 0.8}%
  \begin{titlepage}%
    \setcounter{@thanks}{0}%
    \global\def\thanks@list{}%
    \renewcommand{\thanks}[1]{%
      \listgadd{\thanks@list}{##1}%
      \stepcounter{@thanks}%
      $^\text{\the@thanks}$%
    }%
    \begin{center}%
      \leavevmode\null\par%
      \Large%
      \singlespacing%
      \vspace{\stretch{1}}%
      \begingroup\@suptitle\par\endgroup%
      \vspace{3ex}%
      \begingroup\Huge\@title\par\endgroup%
      \vspace{\stretch{3}}%
      \begin{tabular}[t]{c}%
        \@author%
      \end{tabular}%
      \par%
      \vspace{\stretch{1}}%
      \begingroup\@date\par\endgroup%
      \vspace{\stretch{3}}%
      \begingroup\small{Betreuer:}\par\endgroup%
      \vspace{1ex}%
      \begin{tabular}[t]{c}%
        \@reviewer%
      \end{tabular}%
      \par%
      \vspace{\stretch{2}}%
      \ifnumgreater{\value{@thanks}}{0}{%
        \setcounter{@thanks}{0}%
        \newcommand{\do@thanks}[1]{%
          \stepcounter{@thanks}%
          $^\text{\the@thanks}$##1\par\medskip%
        }%
        \let\do\do@thanks%
        \vspace{\stretch{2}}%
        \begingroup%
          \small%
          \dolistloop{\thanks@list}%
        \endgroup%
        \par%
      }{%
        % no \thanks
      }%
    \end{center}%
  \end{titlepage}%
  \restoregeometry%
}

\newcommand{\makecopypage}{%
  \noindent\leavevmode\null\vfill%
  \begingroup
    \let\thanks\@gobble%
    \setlength{\parindent}{0em}%
    \singlespacing%
    \footnotesize%
    \@copyrightnotice%
    \par%
  \endgroup
  \cleardoublepage%
}

\let\@author\@undefined
\renewcommand*{\author}[2][]{%
  \newcommand*{\@author}{#2}%
  \ifstrempty{#1}{%
    \newcommand*{\@author@short}{#2}%
  }{%
    \newcommand*{\@author@short}{#1}%
  }
}
\newcommand*{\reviewer}[1]{\newcommand*{\@reviewer}{#1}}
\let\@title\@undefined
\renewcommand*{\title}[2][]{%
  \newcommand*{\@title}{#2}%
  \ifstrempty{#1}{%
    \newcommand*{\@title@short}{#2}%
  }{%
    \newcommand*{\@title@short}{#1}%
  }
}
\newcommand*{\suptitle}[1]{\newcommand*{\@suptitle}{#1}}
\let\@date\@undefined
\renewcommand*{\date}[1]{\newcommand*{\@date}{#1}}
\newcommand*{\address}[1]{\newcommand*{\@address}{#1}}
\newcommand{\copyrightnotice}[1]{\newcommand{\@copyrightnotice}{#1}}

\renewenvironment{abstract}{%
  \section*{\abstractname}%
}{%
  \let\thanks\@gobble%
  \par\vspace{3cm}%
  \noindent\leavevmode%
  \@author, \@address{ am }\@date%
  \par%
}

\renewenvironment{quotation}[1][]{%
  \newcommand*{\quotation@author}{#1}%
  \par\noindent\leavevmode%
  \begin{list}{}{\small}%
  \item%
}{%
    \ifdefvoid{\quotation@author}{%
    }{%
      \item\hfill\textsc{\footnotesize\quad\quotation@author}%
    }%
  \end{list}%
  \par%
  \let\quotation@author\@undefined%
}

\defbibheading{bibliography}[\bibname]{\poorsection{#1}}

\newcommand*{\markstuff}[1]{%
  \markboth{\MakeUppercase{#1}}{\MakeUppercase{#1}}
}

\newcommand*{\poorsection}[2][]{%
  \phantomsection%
  \addcontentsline{toc}{section}{\notblank{#1}{#1}{#2}}%
  \section*{#2\markstuff{\notblank{#1}{#1}{#2}}}
}

\DeclareRobustCommand{\email}[1]{\mbox{\href{mailto:#1}{\texttt{#1}}}}

%\setlength{\parindent}{2em}
\setlength{\parskip}{0.5ex plus 1ex minus 0.5ex}
